% gin 2018
% ginters.buss@gmail.com
% this code is an example for seasonally
% adjusting quarterly data and sort of replicates the results 
% of  Buss, Ginters, 2010.
% "Seasonal decomposition with a modified Hodrick-Prescott filter,"
% MPRA Paper 24133, University Library of Munich, Germany.
% <https://ideas.repec.org/p/pra/mprapa/24133.html>

clc;
clear;

% LV gdp data
[data,txt]=xlsread('lv_gdp.xlsx');

ldata = log(data);

% trend component filter with standard HP
% lambda=1600
hp_trend=hpfilter(ldata,1600);
% plot(hp_trend)

% cyclical component filter with standard HP
% lambda=20
hp_cycle=hpfilter(ldata-hp_trend,20);
% plot(hp_cycle)

% seasonal component filter with the modified (seasonal) HP
% s=4 (quarterly data)
% lambda=4
hp_seas=hpfilter_mod(ldata-hp_trend-hp_cycle,4,4);
% plot(hp_seas,'red'); hold on; plot(ldata-hp_trend-hp_cycle, 'blue');
% hold off

% irregular component 
% (ideally should not contain seasonal or cyclical components) 
irreg=ldata-hp_trend-hp_cycle-hp_seas;
% plot(irreg)

% the seasonally adjusted series 
% is then the original series minus the seasonal component

data_sa=exp(ldata-hp_seas);

% plot(data, 'blue'); hold on; plot(data_sa, 'red'); hold off;


