function [hpy]=hpfilter_mod(y,s,lambda)
% gin 2018
% ginters.buss@gmail.com
% PURPOSE: computes the modified (seasonal) HP filter
% in the 3rd step of
% Buss, Ginters, 2010.
% "Seasonal decomposition with a modified Hodrick-Prescott filter,"
% MPRA Paper 24133, University Library of Munich, Germany.
% <https://ideas.repec.org/p/pra/mprapa/24133.html>
% in the first two steps use the standard HP filter

% ------------------------------------------------------------
% INPUT:
% * y = a real (nx1) vector - the series to be filtered
% * s - the seasonality (4 - for quarterly data; 12 - for monthly data, etc)
% * lambda - the smoothing parameter (small; about 4 for quarterly data) 
% ------------------------------------------------------------
% OUPTUT:
% * hpy = vector (nX1) containing filtered data
% ------------------------------------------------------------
% ------------------------------------------------------------


t = size(y,1);

a1=2*lambda+1;

b1=-lambda;

d1=[b1,a1];

d1 = ones(t,1)*d1;

m1 = diag(d1(:,2))+diag(d1(1:t-s,1),-s)+diag(d1(1:t-s,1),s); 

% stabilize the end of sample estimates
m1(1:s,1:s)=eye(s,s)*(1+lambda);
m1(t-(s-1):t,t-(s-1):t)=eye(s,s)*(1+lambda);

hpy = inv(m1)*y;


